${ title }

% if promissory_notes: % endif
% for b_index, b in enumerate(booklets): % if b_index % 4 == 0:
% endif
<%include file="receipt.html" args="b=b" /> <%include file="bill.html" args="b=b" />
% if (b_index+1) % 4 == 0 or b_index == (len(booklets) - 1):
% endif % endfor % if promissory_notes: % for b_index, b in enumerate(booklets): % if b_index % 4 == 0:
% endif <%include file="../base/promissory-note.html" args="b=b" /> % if (b_index+1) % 4 == 0 or b_index == (len(booklets) - 1):
% endif % endfor % endif